@@ -14,7 +14,7 @@
 #   limitations under the License.
 
 __author__ = 'Michael Gruber'
-__version__ = '0.0.11'
+__version__ = '0.0.12'
 
 
 from mock import patch
@@ -29,7 +29,7 @@ MESSAGE_COULD_NOT_VERIFY = 'Could not verify {target_name}.{attribute_name}()'
 MESSAGE_INVALID_ATTRIBUTE = 'The target "{target_name}" has no attribute called "{attribute_name}".'
 MESSAGE_NO_CALLS = """
 Expected: call {target_name}.{attribute_name}()
-     Got: no stubbed function has been called.
+     Got: no patched function has been called.
 """
 MESSAGE_EXPECTED_BUT_WAS = """
 Expected: {expected}
@@ -38,7 +38,7 @@ Expected: {expected}
 
 
 _configurators = {}
-_stubs = []
+_patches = []
 _calls = []
 
 
@@ -49,7 +49,7 @@ class UnitTests(TestCase):
 
     def tearDown(self):
         self.tear_down()
-        unstub()
+        undo_patches()
 
     def set_up(self):
         """ Override this method to set up your unit test environment """
@@ -92,10 +92,10 @@ class FluentAnswer(object):
         return self
 
     def __repr__(self):
-        return "Answer(argument={argument}, values={values})".format(argument=self.arguments, values=self._values)
+        return "Answer(arguments={arguments}, values={values})".format(arguments=self.arguments, values=self._values)
 
 
-class FluentStubEntry(FluentTargeting):
+class FluentPatchEntry(FluentTargeting):
 
     def __init__(self, target, attribute_name, original):
         FluentTargeting.__init__(self, target)
@@ -105,13 +105,13 @@ class FluentStubEntry(FluentTargeting):
         self._mock = None
         self._full_qualified_target_name = None
 
-    def stub_away_with(self, fluent_mock):
+    def patch_away_with(self, fluent_mock):
         self._full_qualified_target_name = self._target_name + '.' + self._attribute_name
         self._patch = patch(self._full_qualified_target_name)
         self._mock = self._patch.__enter__()
         self._mock.side_effect = fluent_mock
 
-    def unstub(self):
+    def undo(self):
         if self._patch:
             self._patch.__exit__()
 
@@ -186,16 +186,24 @@ class FluentWhen(FluentTargeting):
     def __init__(self, target):
         FluentTargeting.__init__(self, target)
 
+    def _get_original_attribute(self, name):
+
+        if not hasattr(self._target, name):
+            error_message = MESSAGE_INVALID_ATTRIBUTE.format(target_name=self._target_name, attribute_name=name)
+            raise FluentMockException(error_message)
+
+        return getattr(self._target, name)
+
     def __getattr__(self, name):
-        original = getattr(self._target, name)
-        stub_entry = FluentStubEntry(self._target, name, original)
-        _stubs.append(stub_entry)
+        original = self._get_original_attribute(name)
+        patch_entry = FluentPatchEntry(self._target, name, original)
+        _patches.append(patch_entry)
 
         key = (self._target, name)
         if not key in _configurators:
             fluent_mock = FluentMock(self._target, name)
             mock_configurator = FluentMockConfigurator(fluent_mock)
-            stub_entry.stub_away_with(fluent_mock)
+            patch_entry.patch_away_with(fluent_mock)
             _configurators[key] = mock_configurator
 
         return _configurators[key]
@@ -252,19 +260,19 @@ def when(target):
     return FluentWhen(target)
 
 
-def unstub():
-    global _calls, _stubs, _configurators
+def undo_patches():
+    global _calls, _patches, _configurators
 
-    for stub in _stubs:
-        stub.unstub()
+    for _patch in _patches:
+        _patch.undo()
 
     _calls = []
-    _stubs = []
+    _patches = []
     _configurators = {}
 
 
-def get_stubs():
-    return _stubs
+def get_patches():
+    return _patches
 
 
 def verify(target):
